package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.ApplicationDataIntegrationServicesMapper;
import com.zyc.system.domain.ApplicationDataIntegrationServices;
import com.zyc.system.service.IApplicationDataIntegrationServicesService;

/**
 * 应用与数据集成平台服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class ApplicationDataIntegrationServicesServiceImpl implements IApplicationDataIntegrationServicesService 
{
    @Autowired
    private ApplicationDataIntegrationServicesMapper applicationDataIntegrationServicesMapper;

    /**
     * 查询应用与数据集成平台服务
     * 
     * @param id 应用与数据集成平台服务主键
     * @return 应用与数据集成平台服务
     */
    @Override
    public ApplicationDataIntegrationServices selectApplicationDataIntegrationServicesById(Integer id)
    {
        return applicationDataIntegrationServicesMapper.selectApplicationDataIntegrationServicesById(id);
    }

    /**
     * 查询应用与数据集成平台服务列表
     * 
     * @param applicationDataIntegrationServices 应用与数据集成平台服务
     * @return 应用与数据集成平台服务
     */
    @Override
    public List<ApplicationDataIntegrationServices> selectApplicationDataIntegrationServicesList(ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        return applicationDataIntegrationServicesMapper.selectApplicationDataIntegrationServicesList(applicationDataIntegrationServices);
    }

    /**
     * 新增应用与数据集成平台服务
     * 
     * @param applicationDataIntegrationServices 应用与数据集成平台服务
     * @return 结果
     */
    @Override
    public int insertApplicationDataIntegrationServices(ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        return applicationDataIntegrationServicesMapper.insertApplicationDataIntegrationServices(applicationDataIntegrationServices);
    }

    /**
     * 修改应用与数据集成平台服务
     * 
     * @param applicationDataIntegrationServices 应用与数据集成平台服务
     * @return 结果
     */
    @Override
    public int updateApplicationDataIntegrationServices(ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        return applicationDataIntegrationServicesMapper.updateApplicationDataIntegrationServices(applicationDataIntegrationServices);
    }

    /**
     * 批量删除应用与数据集成平台服务
     * 
     * @param ids 需要删除的应用与数据集成平台服务主键
     * @return 结果
     */
    @Override
    public int deleteApplicationDataIntegrationServicesByIds(Integer[] ids)
    {
        return applicationDataIntegrationServicesMapper.deleteApplicationDataIntegrationServicesByIds(ids);
    }

    /**
     * 删除应用与数据集成平台服务信息
     * 
     * @param id 应用与数据集成平台服务主键
     * @return 结果
     */
    @Override
    public int deleteApplicationDataIntegrationServicesById(Integer id)
    {
        return applicationDataIntegrationServicesMapper.deleteApplicationDataIntegrationServicesById(id);
    }
}
