package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.ApplicationDataIntegrationServices;
import com.zyc.system.service.IApplicationDataIntegrationServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 应用与数据集成平台服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/ApplicationDataIntegrationServicesController")
public class ApplicationDataIntegrationServicesController extends BaseController
{
    @Autowired
    private IApplicationDataIntegrationServicesService applicationDataIntegrationServicesService;

    /**
     * 查询应用与数据集成平台服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        startPage();
        List<ApplicationDataIntegrationServices> list = applicationDataIntegrationServicesService.selectApplicationDataIntegrationServicesList(applicationDataIntegrationServices);
        return getDataTable(list);
    }

    /**
     * 导出应用与数据集成平台服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "应用与数据集成平台服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        List<ApplicationDataIntegrationServices> list = applicationDataIntegrationServicesService.selectApplicationDataIntegrationServicesList(applicationDataIntegrationServices);
        ExcelUtil<ApplicationDataIntegrationServices> util = new ExcelUtil<ApplicationDataIntegrationServices>(ApplicationDataIntegrationServices.class);
        util.exportExcel(response, list, "应用与数据集成平台服务数据");
    }

    /**
     * 获取应用与数据集成平台服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(applicationDataIntegrationServicesService.selectApplicationDataIntegrationServicesById(id));
    }

    /**
     * 新增应用与数据集成平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "应用与数据集成平台服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        return toAjax(applicationDataIntegrationServicesService.insertApplicationDataIntegrationServices(applicationDataIntegrationServices));
    }

    /**
     * 修改应用与数据集成平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "应用与数据集成平台服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ApplicationDataIntegrationServices applicationDataIntegrationServices)
    {
        return toAjax(applicationDataIntegrationServicesService.updateApplicationDataIntegrationServices(applicationDataIntegrationServices));
    }

    /**
     * 删除应用与数据集成平台服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "应用与数据集成平台服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(applicationDataIntegrationServicesService.deleteApplicationDataIntegrationServicesByIds(ids));
    }
}
